#pragma once

#include <string>
#include <memory>
#include "ofMain.h"

// A shader catalog loads and compiles shaders from a directory. Vertex and
// fragment shaders are matched based on their filename (e.g. example.vert and
// example.frag are loaded and linked together to form the "example" program).
// Whenever a shader file changes on disk, the corresponding program is
// recompiled and relinked.
namespace ofxGPUFont {
class ShaderCatalog {
    public:
        struct Entry {
            GLuint program;

            Entry() : program(0){
            }
            Entry(unsigned int program) : program(program){
            }
        };

        ShaderCatalog(const std::string & dir);
        ~ShaderCatalog();

        void setReplacement(const std::string & a, const std::string & b);
        const std::string & getReplacement(const std::string & a);
        std::shared_ptr <Entry> get(const std::string & name);
        void update();
        void requestUpdate(const std::string & name, bool immediately = false);

    private:
        class Impl;
        std::unique_ptr <Impl> impl;
        const std::string dummy = "";
};
}
